import { Link, useNavigate } from 'react-router-dom'
import { Card, Breadcrumb, Form, Button, Radio, DatePicker, Select, Popconfirm } from 'antd'
import locale from 'antd/es/date-picker/locale/zh_CN'

import { Table, Tag, Space } from 'antd'
import { EditOutlined, DeleteOutlined } from '@ant-design/icons'
import img404 from '@/assets/error.png'

import { useState, useEffect } from 'react'
import { request } from '@/utils'
import { useChannel } from '@/hooks/useChannel'
import { delArticleAPI, getArticleListAPI } from '@/apis/article'

const { Option } = Select
const { RangePicker } = DatePicker



const Article = () => {

    const navagite = useNavigate()

    // 准备列数据
    const columns = [
      {
        title: '封面',
        dataIndex: 'cover',
        width: 120,
        render: cover => {
          return <img src={cover.images[0] || img404} width={80} height={60} alt="" />
        }
      },
      {
        title: '标题',
        dataIndex: 'title',
        width: 220
      },
      {
        title: '状态',
        dataIndex: 'status',
        render: data => data === 1 ? <Tag color='warning'>待审核</Tag>:<Tag color='success'>审核通过</Tag>
      },
      {
        title: '发布时间',
        dataIndex: 'pubdate'
      },
      {
        title: '阅读数',
        dataIndex: 'read_count'
      },
      {
        title: '评论数',
        dataIndex: 'comment_count'
      },
      {
        title: '点赞数',
        dataIndex: 'like_count'
      },
      {
        title: '操作',
        render: data => {
          return (
            <Space size="middle">
              <Button 
                type="primary" 
                shape="circle" 
                icon={<EditOutlined />} 
                onClick={() => navagite(`/publish?id=${data.id}`)} 
              />
              <Popconfirm
                title="确认删除该条文章吗?"
                onConfirm={() => delArticle(data)}
                okText="确认"
                cancelText="取消"
              >
              <Button
                type="primary"
                danger
                shape="circle"
                icon={<DeleteOutlined />}
              />
              </Popconfirm>
            </Space>
          )
        }
      }
    ]
  

  const { channels } = useChannel()

  // 筛选功能
  // 准备参数
  const [reqData, setReqData] = useState({
    status: '',
    channel_id: '',
    begin_pubdate: '',
    end_pubdate: '',
    page: 1,
    per_page: 4
  })

  // 获取文章列表
  const [list, setList] = useState([])
  const [count, setCount] = useState(0)
  useEffect(() => {
    async function getList () {
      const res = await getArticleListAPI(reqData)
      setList(res.data.results)
      setCount(res.data.total_count)
    }
    getList()
  }, [reqData])

  // 获取筛选数据
  const onFinish = (formValue) => {
    console.log(formValue)
    // 把表单收集到数据放到参数中(不可变的方式)
    setReqData({
      ...reqData,
      channel_id: formValue.channel_id,
      status: formValue.status,
      begin_pubdate: formValue.date[0].format('YYYY-MM-DD'),
      end_pubdate: formValue.date[1].format('YYYY-MM-DD')
    })
    // 重新拉取文章列表 + 渲染table逻辑重复的 - 复用
    // reqData依赖项发生变化 重复执行副作用函数 
  }

  const onPageChange = (page) => {
    // 拿到当前页参数 修改引起接口更新
    setReqData({
      ...reqData,
      page
    })
  }

  const delArticle = async (data) => {
    await delArticleAPI(data.id)
    // 更新列表
    setReqData({
      page: 1,
      per_page: 10
    })
  }

  return (
    <div>
      <Card
        title={
          <Breadcrumb items={[
            { title: <Link to={'/'}>首页</Link> },
            { title: '文章列表' },
          ]} />
        }
        style={{ marginBottom: 20 }}
      >
        <Form initialValues={{ status: '' }} onFinish={ onFinish }>
          <Form.Item label="状态" name="status">
            <Radio.Group>
              <Radio value={''}>全部</Radio>
              <Radio value={0}>草稿</Radio>
              <Radio value={2}>审核通过</Radio>
            </Radio.Group>
          </Form.Item>

          <Form.Item label="频道" name="channel_id">
            <Select
              placeholder="请选择文章频道"
              defaultValue=""
              style={{ width: 120 }}
            >
            {channels.map(item => (
              <Option key={item.id} value={item.id}>
                {item.name}
              </Option>
            ))}
            </Select>
          </Form.Item>

          <Form.Item label="日期" name="date">
            {/* 传入locale属性 控制中文显示*/}
            <RangePicker locale={locale}></RangePicker>
          </Form.Item>

          <Form.Item>
            <Button type="primary" htmlType="submit" style={{ marginLeft: 40 }}>
              筛选
            </Button>
          </Form.Item>
        </Form>
      </Card>

      <Card title={`根据筛选条件共查询到 ${count} 条结果：`}>
        <Table dataSource={list} columns={columns} pagination={{
          current: reqData.page,
          pageSize: reqData.per_page,
          onChange: onPageChange,
          total: count
        }}/>
      </Card>

    </div>
  )
}

export default Article
